@@ -1,13 +1,22 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-def hyphenate(text, margin=1):
+def rajaaja(margin, len, merkki):
+	def raja(i):
+		if i > margin and i < len-margin:
+			return merkki
+		else:
+			return ''
+	return raja
+
+def hyphenate(text, margin=1, taboo_chars = []):
 	"""hyphenate_finnish(text, margin=1)
 
 	Hypenates finnish text with Unicode soft hyphens. (U+00AD)
 	Allows to set margins for words so that they won't break right at start or end.
 	For example, it'd be a bit silly to break a word like 'erikoinen' at 'e-rikoinen'.
 	With default margin of 1, it breaks like 'eri-koinen'.
+	If a word contains taboo_characters, it won't get hyphenated.
 	"""
 	
 	# Uh, sorry, my comments are in Finnish. Well, I can hardly think anybody else than Finnish people reading this...
@@ -25,29 +34,32 @@ def hyphenate(text, margin=1):
 	# looppi, jossa siis sanaa edetään kirjain kerrallaan, ja sen mukaan, mitä vastaan tulee, yritetään päätellä tavurakenne
 	
 	for sana in text.split(' '):		# Homma toimii niin, että varmistuneita tavuja tungetaan
+		if any((c in sana) for c in taboo_chars):
+			valmis_teksti.append(sana)
+			continue
+			
+		raja = rajaaja(margin, len(sana), tavuviiva)
+			
 		tavutettu = ''							# tavutettu-muuttujaan
 		buff = ''						# parhaillaan tavu jota kursitaan kasaan, on buffissa.
 		rajatapaus = ''					# rajatapaus tarkoittaa kirjainta, josta ei etukäteen tiedä ...
-												# miten tavuraja menee. esim: ka-Na, kaN-nu
-		raja = ''			# muuttuja raja sisältää tavuviivamerkin, joka tungetaan buffin alkuun, eli tavujen väliin.
+												# miten tavuraja(i) menee. esim: ka-Na, kaN-nu
 		for i, c in enumerate(sana):				# Alla esimerkkikommenteissa iso kirjain senhetkistä 
 															# c-muuttujaa eli käsittelyssä olevaa merkkiä.
 			if c in vokaali:						# Suluissa oleva taas on rajatapaus, joka jäi edelliseltä 
 															# ...kierrokselta epäselväksi kummalle puolelle tavuviivaa kuuluu.
 				if rajatapaus != '':				# ha(l)Oo, a(k)U. jooh, ei pitkää konsonanttia. -> tavuraja
-					buff = raja + rajatapaus+c
+					buff = raja(i-1) + rajatapaus+c
 					rajatapaus = ''
 				elif buff[-2:] in pitkat:			# hääYö, aaAah! kaksi edellistä muodostaa oman tavunsa. -> tavuraja
 					tavutettu += buff
-					raja = tavuviiva
-					buff = raja + c
+					buff = raja(i) + c
 				elif buff[-1:] in vokaali:			# Jos edellinen on vokaali.
 					if buff[-1:]+c in tavuydin:		# kiIski, nuOtta. edellinen ja nykynen muodostavat tavuytimen.
 						buff += c
 					else:							# ta-loA, loAnheitto. eivät muodosta tavuydintä. -> tavuraja
 						tavutettu += buff
-						raja = tavuviiva
-						buff = raja + c
+						buff = raja(i) + c
 				else:								# Aamu, Ilta, kAmpa. kun edellä ei ole 1) epävarmuutta 2) vokaaleja.
 					buff += c
 			elif c in kerake:
@@ -55,7 +67,7 @@ def hyphenate(text, margin=1):
 					if c == rajatapaus and i < len(sana)-1:	# ka(n)Nu, huu(s)Si. kaksi samaa konsonanttia -> tavuraja
 						tavutettu += rajatapaus				# Jännä tietysti et aivan sanan vikalle kirjaimelle tää ei päde.
 						rajatapaus = ''
-						buff = raja + c
+						buff = raja(i) + c
 					else:							# ka(r)Kki, ku(l)Ttuuri, sa(r)Ka tavuydin on jo ohi, 
 														# mutta lopussa onkin yllättävän paljon kamaa! 
 						if tavutettu[-1:] in vokaali:	# esim. särk-kä vai sar-ka? ei tiedetä -> rajatapaus.
@@ -63,41 +75,32 @@ def hyphenate(text, margin=1):
 							rajatapaus = c
 						else:						# ar(s)Ka? kaksi konsonanttia, nyt kyllä viimeistään tavuraja, huh huh
 							tavutettu += rajatapaus
-							raja = tavuviiva
 							rajatapaus = ''
-							buff = raja+ c
+							buff = raja(i) + c
 				elif buff == tavuviiva or buff =='':	# Riku, Kronikka. Puhtaalta pöydältä.
-					buff = raja+ c
+					buff = raja(i-1) + c
 				elif buff[-2:] in pitkat:		# ääLiö vai pääLlikkö? -> rajatapaus.
 					tavutettu += buff
-					raja = tavuviiva
-					buff = raja
+					buff = raja(i)
 					rajatapaus = c
 				elif buff[-1:] in tavuydin:		# kaMa, moKa vai kaMpa, mokKa? -> rajatapaus
 					tavutettu += buff
-					raja = tavuviiva
-					buff = raja
+					buff = raja(i)
 					rajatapaus = c
 				else:							# Mikäs tää olikaan ees?
 					tavutettu += buff
-					buff = raja
+					buff = raja(i)
 					rajatapaus = c
 			else:							# jos se ei ole vokaali tai konsonanntti, se on jokin välimerkki!
 				if rajatapaus != '':		#	japaniN-matka
 					tavutettu += rajatapaus+c
 					rajatapaus = ''
-					raja = ''
 					continue
 				else:							# ??
 					tavutettu += buff+c
-					buff = raja
-					raja = ''
+					buff = raja(i)
 					continue
-			# Tässä on ideana ehkäistä rajojen piirto jos ollaan lähellä sanojen reunoja
-			if i > margin and i < len(sana)-margin:
-				raja = tavuviiva
-			else:
-				raja = ''
+
 		if buff != '' and buff != tavuviiva:
 			tavutettu += buff + rajatapaus
 		else:
